//Create delay function
const delay = ms => new Promise(res => setTimeout(res, ms));

//Tennis court coordinates
//Y: [-5.02m, 5.02m] X: [-11.88m, 11.88m] no Z height
var x = [-11.88, 11.88, 11.88, -11.88]
var y = [-5.02, -5.02, 5.02, 5.02]
//Shift the court slightly up so its not interfering with the grid
var z = [0.01, 0.01, 0.01, 0.01]

//Face is made up of 2 triangles, both need to be set to the same colour
var facecolor = [ 'rgb(30, 175, 0)', 'rgb(30, 175, 0)', ]

var court = { name:"Court", x, y, z, facecolor, type: 'mesh3d', }

var x_val =new Array(); 
var y_val =new Array();
var z_val =new Array();

var trajectory = {
  name: "Trajectory",
  type: 'scatter3d',
  mode: 'lines+markers',
  x: x_val,
  y: y_val,
  z: z_val,
  line: {
    width: 4,
    color: '#ff0000',
  },
  marker: {
    color: '#0000ff',
    size: 2,
    symbol: 'circle',
  },
};

var layout = {
  title: 'Tennis Ball Trajectory Plot',
  autosize: true,
  margin: { autoexpand: true, },
  scene:{
    xaxis:{ range:[-18,18], gridcolor: "#a0a0a0", zerolinecolor: "#a0a0a0", },
    yaxis:{ range:[-10,10], gridcolor: "#a0a0a0", zerolinecolor: "#a0a0a0", },
    zaxis:{ range:[  0, 2], gridcolor: "#a0a0a0", zerolinecolor: "#a0a0a0", },
  }
};

//Init plot
Plotly.newPlot("secondplot", [trajectory,court] , layout, {responsive: true} );

//Update plot with info from GET call
function poll(filename) {
  var jqueryRequest = $.get("http://192.168.0.90:8000/serve/" + filename)
    .done(function(data) {
    Papa.parse(data, {
      dynamicTyping: true,
      delimiter: " ",
      //Only include if the input contains a header row; i.e. the first row is labels.
      //header: true,
      worker: true,
      complete: function(results){
        results.data.forEach((element) => {
          x_val.push(element[2]);
          y_val.push(element[0]);
          //Compensate for court offset
          z_val.push(element[1]+0.01);
        });
        Plotly.update("secondplot", [trajectory,court], layout, {responsive: true});
      },
    });
  }).fail(function(errorData){
    console.error("Backend Request failed! Is the backend running?");
  });
}

//Get the button from the HTML file
var button = document.getElementById("sendPost");

//Get the input field from the HTML file
var input_field = document.getElementById("csvSelector");

//If the user presses "enter" on the input field, call to press the button, as this is expected behaviour
input_field.addEventListener("keypress",function(event){
  if (event.key === "Enter"){
    event.preventDefault();
    button.click();
  }
});

//On button click...
button.addEventListener("click",function(e){
  //Get the file name from the text input
  var file_name = input_field.value;
  //Send the text input to the web server
  $.post("http://192.168.0.90:8000/serve", { file_name })
    //Once the POST response comes back
    .done(function(){
      //Wait 2s for image processing to run
      delay(2000);
      //Clear current  values to graph the new file
      x_val.length = 0;
      y_val.length = 0;
      z_val.length = 0;
      //Run a GET call, with the given file name
      poll(file_name);
    });
},false);
